@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2021 The pyXem developers
+# Copyright 2016-2022 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with pyXem.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Signal class for two-dimensional diffraction data in polar coordinates."""
+
 
 from hyperspy.signals import Signal2D
 from hyperspy._signals.lazy import LazySignal
@@ -26,21 +26,10 @@ from pyxem.signals.common_diffraction import CommonDiffraction
 
 
 class Correlation2D(Signal2D, CommonDiffraction):
+    """Signal class for Correlation data after applying some correlation along some axis.
+    """
     _signal_type = "correlation"
 
-    def __init__(self, *args, **kwargs):
-        """Create a PolarDiffraction2D object from a numpy.ndarray.
-
-        Parameters
-        ----------
-        *args :
-            Passed to the __init__ of Signal2D. The first arg should be
-            a numpy.ndarray
-        **kwargs :
-            Passed to the __init__ of Signal2D
-        """
-        super().__init__(*args, **kwargs)
-
     def get_angular_power(self, inplace=False, **kwargs):
         """Returns the power spectrum of the angular auto-correlation function
         in the form of a Signal2D class.
@@ -66,15 +55,14 @@ class Correlation2D(Signal2D, CommonDiffraction):
             The power spectrum of the Signal2D
         """
         power = self.map(corr_to_power, inplace=inplace, **kwargs)
-        if inplace:
-            self.set_signal_type("power")
-            fourier_axis = self.axes_manager.signal_axes[0]
-        else:
-            power.set_signal_type("power")
-            fourier_axis = self.axes_manager.signal_axes[0]
+
+        s = self if inplace else power
+
+        s.set_signal_type("power")
+        fourier_axis = s.axes_manager.signal_axes[0]
+
         fourier_axis.name = "Fourier Coefficient"
         fourier_axis.units = "a.u"
-        fourier_axis.offset = 0.5
         fourier_axis.scale = 1
         return power
 
@@ -93,16 +81,15 @@ class Correlation2D(Signal2D, CommonDiffraction):
         power: Power2D
             The power spectrum of summed angular correlation
         """
-        power = self.sum().map(corr_to_power, inplace=inplace, **kwargs)
-        if inplace:
-            self.set_signal_type("power")
-            fourier_axis = self.axes_manager.signal_axes[0]
-        else:
-            power.set_signal_type("power")
-            fourier_axis = self.axes_manager.signal_axes[0]
+        power = self.nansum().map(corr_to_power, inplace=inplace, **kwargs)
+
+        s = self if inplace else power
+
+        s.set_signal_type("power")
+        fourier_axis = s.axes_manager.signal_axes[0]
+
         fourier_axis.name = "Fourier Coefficient"
         fourier_axis.units = "a.u"
-        fourier_axis.offset = 0.5
         fourier_axis.scale = 1
         return power
 
