@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2020 The pyXem developers
+# Copyright 2016-2022 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -16,28 +16,31 @@
 # You should have received a copy of the GNU General Public License
 # along with pyXem.  If not, see <http://www.gnu.org/licenses/>.
 
+import itertools
+from warnings import warn
+
 import numpy as np
-
-from hyperspy.signals import BaseSignal, Signal1D
-from hyperspy.api import markers
-
 import matplotlib.pyplot as plt
 from matplotlib.cm import get_cmap
 from scipy.spatial import distance_matrix
 from sklearn.cluster import DBSCAN
 
-from warnings import warn
+from hyperspy.signals import BaseSignal, Signal1D
+from hyperspy.api import markers
 
-from pyxem.signals import (
+from pyxem.utils.signal import (
     transfer_navigation_axes,
     transfer_navigation_axes_to_signal_axes,
 )
-from pyxem.utils.vector_utils import detector_to_fourier
-from pyxem.utils.vector_utils import calculate_norms, calculate_norms_ragged
-from pyxem.utils.vector_utils import get_npeaks, filter_vectors_ragged
-from pyxem.utils.vector_utils import filter_vectors_edge_ragged
+from pyxem.utils.vector_utils import (
+    detector_to_fourier,
+    calculate_norms,
+    calculate_norms_ragged,
+    get_npeaks,
+    filter_vectors_ragged,
+    filter_vectors_edge_ragged,
+)
 from pyxem.utils.expt_utils import peaks_as_gvectors
-from pyxem.utils.plot import generate_marker_inputs_from_peaks
 
 
 """
@@ -54,6 +57,63 @@ number of peaks.
 """
 
 
+def _find_max_length_peaks(peaks):
+    """Worker function for generate_marker_inputs_from_peaks.
+
+    Parameters
+    ----------
+    peaks : :class:`pyxem.diffraction_vectors.DiffractionVectors`
+        Identified peaks in a diffraction signal.
+
+    Returns
+    -------
+    longest_length : int
+        The length of the longest peak list.
+
+    """
+    length_of_longest_peaks_list = 0
+    with peaks.unfolded(unfold_navigation=True, unfold_signal=False):
+        for array in peaks.data:
+            if array.shape[0] > length_of_longest_peaks_list:
+                length_of_longest_peaks_list = array.shape[0]
+    return length_of_longest_peaks_list
+
+
+def generate_marker_inputs_from_peaks(peaks):
+    """Takes a peaks (defined in 2D) object from a STEM (more than 1 image) scan
+    and returns markers.
+
+    Parameters
+    ----------
+    peaks : :class:`pyxem.diffraction_vectors.DiffractionVectors`
+        Identifies peaks in a diffraction signal.
+
+    Example
+    -------
+    How to get these onto images::
+
+        mmx,mmy = generate_marker_inputs_from_peaks(found_peaks)
+        dp.plot(cmap='viridis')
+        for mx,my in zip(mmx,mmy):
+            m = hs.markers.point(x=mx,y=my,color='red',marker='x')
+            dp.add_marker(m,plot_marker=True,permanent=False)
+
+    """
+    max_peak_len = _find_max_length_peaks(peaks)
+    if peaks.data.dtype == np.dtype("O"):
+        navshape = peaks.data.shape
+    else:
+        navshape = peaks.axes_manager.navigation_shape[::-1]
+    pad = np.full((max_peak_len, *navshape, 2), np.nan)
+    for coordinate in np.ndindex(navshape):
+        array = peaks.data[coordinate]
+        sl = (slice(0, array.shape[0]), *coordinate, slice(None))
+        pad[sl] = array
+    x = pad[..., 0]
+    y = pad[..., 1]
+    return x, y
+
+
 class DiffractionVectors(BaseSignal):
     """Crystallographic mapping results containing the best matching crystal
     phase and orientation at each navigation position with associated metrics.
@@ -290,7 +350,7 @@ class DiffractionVectors(BaseSignal):
         # If ragged the signal axes will not be defined
         if len(self.axes_manager.signal_axes) == 0:
             magnitudes = self.map(
-                calculate_norms_ragged, inplace=False, *args, **kwargs
+                calculate_norms_ragged, inplace=False,ragged=True, *args, **kwargs
             )
         # Otherwise easier to calculate.
         else:
@@ -497,6 +557,7 @@ class DiffractionVectors(BaseSignal):
                 min_magnitude=min_magnitude,
                 max_magnitude=max_magnitude,
                 inplace=False,
+                ragged=True,
                 *args,
                 **kwargs
             )
@@ -551,6 +612,7 @@ class DiffractionVectors(BaseSignal):
                 x_threshold=x_threshold,
                 y_threshold=y_threshold,
                 inplace=False,
+                ragged=True,
                 *args,
                 **kwargs
             )
@@ -627,6 +689,7 @@ class DiffractionVectors(BaseSignal):
             camera_length=camera_length * 1e10,
             inplace=False,
             parallel=False,  # TODO: For testing
+            ragged=True,
             *args,
             **kwargs
         )
